@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright 2018,2020 Thomas E. Dickey                                     *
+ * Copyright 2018-2020,2024 Thomas E. Dickey                                *
  * Copyright 1998-2012,2016 Free Software Foundation, Inc.                  *
  *                                                                          *
  * Permission is hereby granted, free of charge, to any person obtaining a  *
@@ -33,7 +33,7 @@
 
 #include "form.priv.h"
 
-MODULE_ID("$Id: fld_arg.c,v 1.17 2020/05/24 01:40:20 anonymous.maarten Exp $")
+MODULE_ID("$Id: fld_arg.c,v 1.19 2024/12/07 23:00:37 tom Exp $")
 
 /*---------------------------------------------------------------------------
 |   Facility      :  libnform
@@ -75,7 +75,7 @@ set_fieldtype_arg(FIELDTYPE *typ,
      TR_FUNC_ARG(1, copy_arg),
      TR_FUNC_ARG(2, free_arg)));
 
-  if (typ != 0 && make_arg != (void *)0)
+  if (typ != NULL && make_arg != NULL)
     {
       SetStatus(typ, _HAS_ARGS);
       typ->makearg = make_arg;
@@ -90,7 +90,7 @@ set_fieldtype_arg(FIELDTYPE *typ,
 |   Facility      :  libnform
 |   Function      :  void *field_arg(const FIELD *field)
 |
-|   Description   :  Retrieve pointer to the fields argument structure.
+|   Description   :  Retrieve pointer to the field's argument structure.
 |
 |   Return Values :  Pointer to structure or NULL if none is defined.
 +--------------------------------------------------------------------------*/
