@@ -35,7 +35,7 @@
  ****************************************************************************/
 
 /*
- * $Id: curses.priv.h,v 1.732 2025/11/16 16:08:54 tom Exp $
+ * $Id: curses.priv.h,v 1.742 2025/12/31 14:30:54 tom Exp $
  *
  *	curses.priv.h
  *
@@ -90,10 +90,8 @@ extern int errno;
 /* Some Windows related defines */
 
 #undef _NC_WINDOWS
-#if (defined(_WIN32) || defined(_WIN64__) || defined(__MSYS__) || defined(__CYGWIN__))
+#if (defined(_WIN32) || defined(_WIN64__) || defined(__MSYS__))
 #define _NC_WINDOWS
-#else
-#undef EXP_WIN32_DRIVER
 #endif
 
 #undef _NC_CYGWIN
@@ -313,7 +311,7 @@ extern NCURSES_EXPORT(void *) _nc_memmove (void *, const void *, size_t);
 /*
  * Options for terminal drivers, etc...
  */
-#ifdef USE_TERM_DRIVER
+#if USE_TERM_DRIVER
 #define NO_TERMINAL "unknown"
 #define USE_SP_RIPOFF     1
 #define USE_SP_TERMTYPE   1
@@ -420,8 +418,21 @@ typedef TRIES {
 #define TWAIT_MASK TW_ANY
 #endif
 
-#if defined(_NC_WINDOWS)
+#include <term.priv.h>		/* defines TERMIOS via term.h */
+
+#if USE_TERM_DRIVER
+#if defined(TERMIOS)
+#undef  USE_NAMED_PIPES
+#define USE_NAMED_PIPES 0
+#undef  USE_WIN32CON_DRIVER
+#elif defined(_NC_WINDOWS)
 #include <nc_win32.h>
+#endif /* TERMIOS */
+#endif /* USE_TERM_DRIVER */
+
+#ifndef FixupPathname
+#define FixupPathname(path) /* nothing */
+#define FixupPathname2(path,buffer) /* nothing */
 #endif
 
 typedef struct
@@ -467,7 +478,6 @@ typedef union {
 
 #include <nc_panel.h>
 
-#include <term.priv.h>
 #include <nc_termios.h>
 
 #define IsPreScreen(sp)      (((sp) != NULL) && sp->_prescreen)
@@ -835,7 +845,7 @@ typedef enum {
 #if USE_SYSMOUSE
 	,M_SYSMOUSE		/* FreeBSD sysmouse on console */
 #endif
-#ifdef USE_TERM_DRIVER
+#if USE_TERM_DRIVER
 	,M_TERM_DRIVER		/* Win32 console, etc */
 #endif
 } MouseType;
@@ -941,10 +951,16 @@ typedef int (*TYPE_Gpm_GetEvent) (Gpm_Event *);
  * The filesystem database normally uses a single-letter for the lower level
  * of directories.  Use a hexadecimal code for filesystems which do not
  * preserve mixed-case names.
+ *
+ * The leading "./" is used in _nc_to_dospath() to decide whether to prefix
+ * the converted path with the MinGW32 base directory.
  */
 #if MIXEDCASE_FILENAMES
 #define LEAF_FMT "%c"
 #define LEAF_LEN 1
+#elif USE_DOS_PATHS
+#define LEAF_FMT "./%02x"
+#define LEAF_LEN 4
 #else
 #define LEAF_FMT "%02x"
 #define LEAF_LEN 2
@@ -961,7 +977,7 @@ typedef int (*TYPE_Gpm_GetEvent) (Gpm_Event *);
 #define TRACEMSE_MAX	(80 + (5 * 10) + (32 * 15))
 #define TRACEMSE_FMT	"id %2d  at (%2d, %2d, %2d) state %4lx = {" /* } */
 
-#ifdef USE_TERM_DRIVER
+#if USE_TERM_DRIVER
 struct DriverTCB; /* Terminal Control Block forward declaration */
 #define INIT_TERM_DRIVER()	_nc_globals.term_driver = _nc_get_driver
 #else
@@ -1239,7 +1255,7 @@ typedef struct screen {
 	int		_sysmouse_new_buttons;
 #endif
 
-#if defined(USE_TERM_DRIVER) || defined(EXP_WIN32_DRIVER)
+#if USE_TERM_DRIVER || USE_NAMED_PIPES
 	MEVENT		_drv_mouse_fifo[FIFO_SIZE];
 	int		_drv_mouse_head;
 	int		_drv_mouse_tail;
@@ -2278,7 +2294,7 @@ extern NCURSES_EXPORT(int) _nc_eventlist_timeout(_nc_eventlist *);
  */
 #if USE_WIDEC_SUPPORT
 
-#if defined(_NC_WINDOWS_NATIVE) && !defined(_NC_MSC) && !defined(EXP_WIN32_DRIVER)
+#if defined(_NC_WINDOWS_NATIVE) && !defined(_NC_MSC) && !USE_NAMED_PIPES
 /*
  * MinGW has wide-character functions, but they do not work correctly.
  */
@@ -2404,7 +2420,7 @@ extern NCURSES_EXPORT(int) _nc_get_tty_mode(TTY *);
     }\
     sp->jump = outc
 
-#ifdef USE_TERM_DRIVER
+#if USE_TERM_DRIVER
 
 typedef struct _termInfo
 {
@@ -2501,7 +2517,7 @@ extern NCURSES_EXPORT(void)     _nc_get_screensize_ex(SCREEN *, TERMINAL *, int
  * Entrypoints which are actually provided in the terminal driver, which would
  * be an sp-name otherwise.
  */
-#ifdef USE_TERM_DRIVER
+#if USE_TERM_DRIVER
 #define TINFO_HAS_KEY           _nc_tinfo_has_key
 #define TINFO_DOUPDATE          _nc_tinfo_doupdate
 #define TINFO_MVCUR             _nc_tinfo_mvcur
@@ -2530,7 +2546,7 @@ extern NCURSES_EXPORT(int)      TINFO_MVCUR(SCREEN*, int, int, int, int);
 /*
  * Entrypoints using an extra parameter with the terminal driver.
  */
-#ifdef USE_TERM_DRIVER
+#if USE_TERM_DRIVER
 extern NCURSES_EXPORT(void)   _nc_get_screensize(SCREEN *, TERMINAL *, int *, int *);
 extern NCURSES_EXPORT(int)    _nc_setupterm_ex(TERMINAL **, const char *, int , int *, int);
 #define TINFO_GET_SIZE(sp, tp, lp, cp) \
@@ -2549,30 +2565,19 @@ extern NCURSES_EXPORT(void)   _nc_get_screensize(SCREEN *, int *, int *);
 	_nc_setupterm(name, fd, err, reuse)
 #endif /* !USE_TERM_DRIVER */
 
-#ifdef EXP_WIN32_DRIVER
-extern NCURSES_EXPORT_VAR(TERM_DRIVER) _nc_TINFO_DRIVER;
+#if USE_TERM_DRIVER
 extern NCURSES_EXPORT_VAR(TERM_DRIVER) _nc_WIN_DRIVER;
-#else
-#ifdef USE_TERM_DRIVER
-#if defined(USE_WIN32CON_DRIVER)
-extern NCURSES_EXPORT_VAR(TERM_DRIVER) _nc_WIN_DRIVER;
-extern NCURSES_EXPORT(bool) _nc_mingw_init(void);
-#ifdef TERMIOS
-extern NCURSES_EXPORT(int) _nc_mingw_tcflush(int fd, int queue);
-extern NCURSES_EXPORT(int) _nc_mingw_tcgetattr(int fd, struct termios *arg);
-extern NCURSES_EXPORT(int)  _nc_mingw_tcsetattr(int fd, int optional_actions, const struct termios* arg);
-#endif
-#endif
 extern NCURSES_EXPORT_VAR(TERM_DRIVER) _nc_TINFO_DRIVER;
 #endif /* USE_TERM_DRIVER */
-#endif /* EXP_WIN32_DRIVER */
 
-#ifdef _NC_WINDOWS
-
-extern NCURSES_EXPORT(bool)  _nc_console_checkinit(bool initFlag, bool assumeTermInfo);
+#ifdef TERMIOS
+#define USE_WINCONMODE 0
+#elif defined(USE_WIN32CON_DRIVER)
+#define USE_WINCONMODE 1
+extern NCURSES_EXPORT(int)  _nc_console_setmode(void* handle, const ConsoleMode* arg);
+extern NCURSES_EXPORT(int)  _nc_console_getmode(void* handle, ConsoleMode* arg);
+extern NCURSES_EXPORT(bool)  _nc_console_checkinit(bool assumeTermInfo);
 extern NCURSES_EXPORT(void*) _nc_console_fd2handle(int fd);
-extern NCURSES_EXPORT(int)  _nc_console_setmode(void* handle, const struct winconmode* arg);
-extern NCURSES_EXPORT(int)  _nc_console_getmode(void* handle, struct winconmode* arg);
 extern NCURSES_EXPORT(WORD) _nc_console_MapColor(bool fore, int color);
 extern NCURSES_EXPORT(int)  _nc_console_flush(void* handle);
 extern NCURSES_EXPORT(bool) _nc_console_get_SBI(void);
@@ -2594,9 +2599,11 @@ extern NCURSES_EXPORT(int)  _nc_console_vt_supported(void);
 extern NCURSES_EXPORT(int)    _nc_console_checkmintty(int fd, LPHANDLE pMinTTY);
 #endif
 
-#endif /* _NC_WINDOWS */
+#else
+#error unsupported driver configuration
+#endif /* USE_WIN32CON_DRIVER */
 
-#if defined(USE_TERM_DRIVER) && (defined(EXP_WIN32_DRIVER) || defined(USE_WIN32CON_DRIVER))
+#if USE_TERM_DRIVER && defined(USE_WIN32CON_DRIVER)
 #define NC_ISATTY(fd) (0 != _nc_console_isatty(fd))
 #else
 #define NC_ISATTY(fd) isatty(fd)
@@ -2610,10 +2617,10 @@ extern NCURSES_EXPORT(int)    _nc_console_checkmintty(int fd, LPHANDLE pMinTTY);
 	 && (value = ttyname(fd)) != NULL \
 	 && strncmp(value, "/dev/pts/", 9))
 
-#ifdef USE_TERM_DRIVER
-#  define IsTermInfo(sp)       ((TCBOf(sp) != NULL) && ((TCBOf(sp)->drv->isTerminfo)))
+#if USE_TERM_DRIVER
+#  define IsTermInfo(sp)       ((TCBOf(sp) != NULL) && ((TCBOf(sp)->drv != NULL)) && ((TCBOf(sp)->drv->isTerminfo)))
 #  define HasTInfoTerminal(sp) ((NULL != TerminalOf(sp)) && IsTermInfo(sp))
-#  if defined(EXP_WIN32_DRIVER)
+#  if USE_NAMED_PIPES
 #    define IsTermInfoOnConsole(sp) (IsTermInfo(sp) && _nc_console_test(TerminalOf(sp)->Filedes))
 #  elif defined(USE_WIN32CON_DRIVER)
 #    define IsTermInfoOnConsole(sp) (IsTermInfo(sp) && _nc_console_test(TerminalOf(sp)->Filedes))
@@ -2623,7 +2630,7 @@ extern NCURSES_EXPORT(int)    _nc_console_checkmintty(int fd, LPHANDLE pMinTTY);
 #else
 #  define IsTermInfo(sp)       TRUE
 #  define HasTInfoTerminal(sp) (NULL != TerminalOf(sp))
-#  if defined(EXP_WIN32_DRIVER)
+#  if USE_NAMED_PIPES
 #    define IsTermInfoOnConsole(sp) _nc_console_test(TerminalOf(sp)->Filedes)
 #  else
 #    define IsTermInfoOnConsole(sp) FALSE
